@@ -719,6 +719,22 @@ testParseOnly('Version 5 PUBACK test 1', {
 )
 
 testParseAndGenerate('Version 5 PUBACK test 2', {
+  cmd: 'puback',
+  messageId: 42,
+  retain: false,
+  qos: 0,
+  dup: false,
+  length: 2,
+  topic: null,
+  payload: null,
+  reasonCode: 0
+}, Buffer.from([
+  64, 2, // Fixed Header (PUBACK, Remaining Length)
+  0, 42 // Variable Header (2 Bytes: Packet Identifier 42, Implied reason code: 0 Success, Implied no properties)
+]), { protocolVersion: 5 }
+)
+
+testParseOnly('Version 5 PUBACK test 2.1', {
   cmd: 'puback',
   messageId: 42,
   retain: false,
@@ -1770,8 +1786,8 @@ test('split publish longer', t => {
     retain: false,
     qos: 0,
     dup: false,
-    length: length,
-    topic: topic,
+    length,
+    topic,
     payload: Buffer.from('a'.repeat(payloadLength))
   }
 
@@ -1802,8 +1818,8 @@ test('split length parse', t => {
     retain: false,
     qos: 0,
     dup: false,
-    length: length,
-    topic: topic,
+    length,
+    topic,
     payload: Buffer.from('a'.repeat(payloadLength))
   }
 
@@ -1868,18 +1884,32 @@ testParseError('Invalid header flag bits, must be 0x0 for puback packet', Buffer
   0, 2 // Message ID
 ]))
 
+testParseGenerate('puback without reason and no MQTT 5 properties', {
+  cmd: 'puback',
+  retain: false,
+  qos: 0,
+  dup: false,
+  length: 2,
+  messageId: 2,
+  reasonCode: 0
+}, Buffer.from([
+  64, 2, // Header
+  0, 2 // Message ID
+]), { protocolVersion: 5 })
+
 testParseGenerate('puback with reason and no MQTT 5 properties', {
   cmd: 'puback',
   retain: false,
   qos: 0,
   dup: false,
-  length: 3,
+  length: 4,
   messageId: 2,
   reasonCode: 16
 }, Buffer.from([
-  64, 3, // Header
+  64, 4, // Header
   0, 2, // Message ID
-  16 // reason code
+  16, // reason code
+  0 // no user properties
 ]), { protocolVersion: 5 })
 
 testParseGenerate('puback MQTT 5 properties', {
